@@ -29,9 +29,9 @@ from shapely.geometry import LineString
 import itertools
 import numpy
 # mine
-import HandwrittenData
-import preprocessing
-import utils
+from . import HandwrittenData
+from . import preprocessing
+from . import utils
 
 
 def get_class(name):
